==> opensaml-soap-impl-3.4.3-sources.jar: org/opensaml/soap/wssecurity/impl/AttributedURIMarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import net.shibboleth.utilities.java.support.xml.ElementSupport;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.core.xml.util.XMLObjectSupport;
import org.opensaml.soap.wssecurity.AttributedURI;
import org.w3c.dom.Element;

import com.google.common.base.Strings;

/**
 * Marshaller for instances of {@link AttributedURI}.
 */
public class AttributedURIMarshaller extends AbstractWSSecurityObjectMarshaller {

    /** {@inheritDoc} */
    protected void marshallAttributes(final XMLObject xmlObject, final Element domElement) throws MarshallingException {
        final AttributedURI attributedURI = (AttributedURI) xmlObject;
        
        if (!Strings.isNullOrEmpty(attributedURI.getWSUId())) {
            XMLObjectSupport.marshallAttribute(AttributedURI.WSU_ID_ATTR_NAME, attributedURI.getWSUId(), domElement,
                    true);
        }
        
        XMLObjectSupport.marshallAttributeMap(attributedURI.getUnknownAttributes(), domElement);
        
    }

    /** {@inheritDoc} */
    protected void marshallElementContent(final XMLObject xmlObject, final Element domElement)
            throws MarshallingException {
        final AttributedURI attributedURI = (AttributedURI) xmlObject;
        ElementSupport.appendTextContent(domElement, attributedURI.getValue());
    }
    
}

==> opensaml-soap-impl-4.2.0-sources.jar: org/opensaml/soap/wssecurity/impl/AttributedURIMarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.core.xml.schema.impl.XSURIMarshaller;
import org.opensaml.core.xml.util.XMLObjectSupport;
import org.opensaml.soap.wssecurity.AttributedURI;
import org.w3c.dom.Element;

import com.google.common.base.Strings;

/**
 * Marshaller for instances of {@link AttributedURI}.
 */
public class AttributedURIMarshaller extends XSURIMarshaller {

    /** {@inheritDoc} */
    protected void marshallAttributes(final XMLObject xmlObject, final Element domElement) throws MarshallingException {
        final AttributedURI attributedURI = (AttributedURI) xmlObject;
        
        if (!Strings.isNullOrEmpty(attributedURI.getWSUId())) {
            XMLObjectSupport.marshallAttribute(AttributedURI.WSU_ID_ATTR_NAME, attributedURI.getWSUId(), domElement,
                    true);
        }
        
        XMLObjectSupport.marshallAttributeMap(attributedURI.getUnknownAttributes(), domElement);
        
    }
    
}
